# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ModelRouterQueryConversationListResponseBody(DaraModel):
    def __init__(
        self,
        data: main_models.ModelRouterQueryConversationListResponseBodyData = None,
        err_code: str = None,
        err_message: str = None,
        http_status_code: int = None,
        request_id: str = None,
        success: bool = None,
    ):
        self.data = data
        self.err_code = err_code
        self.err_message = err_message
        self.http_status_code = http_status_code
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['data'] = self.data.to_map()

        if self.err_code is not None:
            result['errCode'] = self.err_code

        if self.err_message is not None:
            result['errMessage'] = self.err_message

        if self.http_status_code is not None:
            result['httpStatusCode'] = self.http_status_code

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('data') is not None:
            temp_model = main_models.ModelRouterQueryConversationListResponseBodyData()
            self.data = temp_model.from_map(m.get('data'))

        if m.get('errCode') is not None:
            self.err_code = m.get('errCode')

        if m.get('errMessage') is not None:
            self.err_message = m.get('errMessage')

        if m.get('httpStatusCode') is not None:
            self.http_status_code = m.get('httpStatusCode')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        return self

class ModelRouterQueryConversationListResponseBodyData(DaraModel):
    def __init__(
        self,
        list: List[main_models.ConversationDTO] = None,
        max_result: str = None,
        next_token: str = None,
        page: int = None,
        page_size: int = None,
        total: int = None,
    ):
        self.list = list
        self.max_result = max_result
        self.next_token = next_token
        self.page = page
        self.page_size = page_size
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['list'] = []
        if self.list is not None:
            for k1 in self.list:
                result['list'].append(k1.to_map() if k1 else None)

        if self.max_result is not None:
            result['maxResult'] = self.max_result

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.page is not None:
            result['page'] = self.page

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.total is not None:
            result['total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.list = []
        if m.get('list') is not None:
            for k1 in m.get('list'):
                temp_model = main_models.ConversationDTO()
                self.list.append(temp_model.from_map(k1))

        if m.get('maxResult') is not None:
            self.max_result = m.get('maxResult')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('page') is not None:
            self.page = m.get('page')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('total') is not None:
            self.total = m.get('total')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class OrgInitResultDTO(DaraModel):
    def __init__(
        self,
        api_key: str = None,
        client_id: int = None,
        client_uuid: str = None,
        is_new: bool = None,
        org_id: int = None,
        user_id: int = None,
    ):
        self.api_key = api_key
        self.client_id = client_id
        self.client_uuid = client_uuid
        self.is_new = is_new
        self.org_id = org_id
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.api_key is not None:
            result['apiKey'] = self.api_key

        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.client_uuid is not None:
            result['clientUuid'] = self.client_uuid

        if self.is_new is not None:
            result['isNew'] = self.is_new

        if self.org_id is not None:
            result['orgId'] = self.org_id

        if self.user_id is not None:
            result['userId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('apiKey') is not None:
            self.api_key = m.get('apiKey')

        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('clientUuid') is not None:
            self.client_uuid = m.get('clientUuid')

        if m.get('isNew') is not None:
            self.is_new = m.get('isNew')

        if m.get('orgId') is not None:
            self.org_id = m.get('orgId')

        if m.get('userId') is not None:
            self.user_id = m.get('userId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class UsageBreakdownRowDTO(DaraModel):
    def __init__(
        self,
        client_id: int = None,
        client_name: str = None,
        metrics: List[main_models.MetricKVPairDTO] = None,
        model_code: str = None,
        model_id: int = None,
        model_name: str = None,
        model_type: str = None,
        summary_time: int = None,
    ):
        self.client_id = client_id
        self.client_name = client_name
        self.metrics = metrics
        self.model_code = model_code
        self.model_id = model_id
        self.model_name = model_name
        self.model_type = model_type
        self.summary_time = summary_time

    def validate(self):
        if self.metrics:
            for v1 in self.metrics:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.client_name is not None:
            result['clientName'] = self.client_name

        result['metrics'] = []
        if self.metrics is not None:
            for k1 in self.metrics:
                result['metrics'].append(k1.to_map() if k1 else None)

        if self.model_code is not None:
            result['modelCode'] = self.model_code

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.model_name is not None:
            result['modelName'] = self.model_name

        if self.model_type is not None:
            result['modelType'] = self.model_type

        if self.summary_time is not None:
            result['summaryTime'] = self.summary_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('clientName') is not None:
            self.client_name = m.get('clientName')

        self.metrics = []
        if m.get('metrics') is not None:
            for k1 in m.get('metrics'):
                temp_model = main_models.MetricKVPairDTO()
                self.metrics.append(temp_model.from_map(k1))

        if m.get('modelCode') is not None:
            self.model_code = m.get('modelCode')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('modelName') is not None:
            self.model_name = m.get('modelName')

        if m.get('modelType') is not None:
            self.model_type = m.get('modelType')

        if m.get('summaryTime') is not None:
            self.summary_time = m.get('summaryTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class PaidResourceDTO(DaraModel):
    def __init__(
        self,
        effective_time: str = None,
        expire_time: str = None,
        instance_id: str = None,
        quantity: int = None,
        remain_quantity: int = None,
        resource_catalog_code: str = None,
        resource_catalog_name: str = None,
        resource_package_code: str = None,
        resource_package_name: str = None,
        resource_status: str = None,
    ):
        self.effective_time = effective_time
        self.expire_time = expire_time
        self.instance_id = instance_id
        self.quantity = quantity
        self.remain_quantity = remain_quantity
        self.resource_catalog_code = resource_catalog_code
        self.resource_catalog_name = resource_catalog_name
        self.resource_package_code = resource_package_code
        self.resource_package_name = resource_package_name
        self.resource_status = resource_status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.effective_time is not None:
            result['effectiveTime'] = self.effective_time

        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.quantity is not None:
            result['quantity'] = self.quantity

        if self.remain_quantity is not None:
            result['remainQuantity'] = self.remain_quantity

        if self.resource_catalog_code is not None:
            result['resourceCatalogCode'] = self.resource_catalog_code

        if self.resource_catalog_name is not None:
            result['resourceCatalogName'] = self.resource_catalog_name

        if self.resource_package_code is not None:
            result['resourcePackageCode'] = self.resource_package_code

        if self.resource_package_name is not None:
            result['resourcePackageName'] = self.resource_package_name

        if self.resource_status is not None:
            result['resourceStatus'] = self.resource_status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('effectiveTime') is not None:
            self.effective_time = m.get('effectiveTime')

        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('quantity') is not None:
            self.quantity = m.get('quantity')

        if m.get('remainQuantity') is not None:
            self.remain_quantity = m.get('remainQuantity')

        if m.get('resourceCatalogCode') is not None:
            self.resource_catalog_code = m.get('resourceCatalogCode')

        if m.get('resourceCatalogName') is not None:
            self.resource_catalog_name = m.get('resourceCatalogName')

        if m.get('resourcePackageCode') is not None:
            self.resource_package_code = m.get('resourcePackageCode')

        if m.get('resourcePackageName') is not None:
            self.resource_package_name = m.get('resourcePackageName')

        if m.get('resourceStatus') is not None:
            self.resource_status = m.get('resourceStatus')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import Any

from darabonba.model import DaraModel

class ModelRouterCreateBillingRuleRequest(DaraModel):
    def __init__(
        self,
        billing_type: str = None,
        effective_time: str = None,
        expire_time: str = None,
        model_id: int = None,
        pricing_config: Any = None,
        version: int = None,
    ):
        self.billing_type = billing_type
        self.effective_time = effective_time
        self.expire_time = expire_time
        # This parameter is required.
        self.model_id = model_id
        self.pricing_config = pricing_config
        self.version = version

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.billing_type is not None:
            result['billingType'] = self.billing_type

        if self.effective_time is not None:
            result['effectiveTime'] = self.effective_time

        if self.expire_time is not None:
            result['expireTime'] = self.expire_time

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.pricing_config is not None:
            result['pricingConfig'] = self.pricing_config

        if self.version is not None:
            result['version'] = self.version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('billingType') is not None:
            self.billing_type = m.get('billingType')

        if m.get('effectiveTime') is not None:
            self.effective_time = m.get('effectiveTime')

        if m.get('expireTime') is not None:
            self.expire_time = m.get('expireTime')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('pricingConfig') is not None:
            self.pricing_config = m.get('pricingConfig')

        if m.get('version') is not None:
            self.version = m.get('version')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModelRouterQueryObservationLogsRequest(DaraModel):
    def __init__(
        self,
        api_key_id: int = None,
        client_id: int = None,
        end_time: str = None,
        group_by: str = None,
        max_results: int = None,
        model_id: int = None,
        need_total_count: bool = None,
        next_token: str = None,
        order_by: str = None,
        order_direction: str = None,
        page_index: int = None,
        page_size: int = None,
        start_time: str = None,
        time_range: str = None,
    ):
        self.api_key_id = api_key_id
        self.client_id = client_id
        self.end_time = end_time
        self.group_by = group_by
        self.max_results = max_results
        self.model_id = model_id
        self.need_total_count = need_total_count
        self.next_token = next_token
        self.order_by = order_by
        self.order_direction = order_direction
        self.page_index = page_index
        self.page_size = page_size
        self.start_time = start_time
        self.time_range = time_range

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.api_key_id is not None:
            result['apiKeyId'] = self.api_key_id

        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.group_by is not None:
            result['groupBy'] = self.group_by

        if self.max_results is not None:
            result['maxResults'] = self.max_results

        if self.model_id is not None:
            result['modelId'] = self.model_id

        if self.need_total_count is not None:
            result['needTotalCount'] = self.need_total_count

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        if self.order_by is not None:
            result['orderBy'] = self.order_by

        if self.order_direction is not None:
            result['orderDirection'] = self.order_direction

        if self.page_index is not None:
            result['pageIndex'] = self.page_index

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.time_range is not None:
            result['timeRange'] = self.time_range

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('apiKeyId') is not None:
            self.api_key_id = m.get('apiKeyId')

        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('groupBy') is not None:
            self.group_by = m.get('groupBy')

        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        if m.get('modelId') is not None:
            self.model_id = m.get('modelId')

        if m.get('needTotalCount') is not None:
            self.need_total_count = m.get('needTotalCount')

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        if m.get('orderBy') is not None:
            self.order_by = m.get('orderBy')

        if m.get('orderDirection') is not None:
            self.order_direction = m.get('orderDirection')

        if m.get('pageIndex') is not None:
            self.page_index = m.get('pageIndex')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('timeRange') is not None:
            self.time_range = m.get('timeRange')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class OralEvaluationStatisticsErrorCountResponse(DaraModel):
    def __init__(
        self,
        project_data: main_models.OralEvaluationStatisticsErrorCountResponseProjectData = None,
        project_id: str = None,
    ):
        self.project_data = project_data
        # This parameter is required.
        self.project_id = project_id

    def validate(self):
        if self.project_data:
            self.project_data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.project_data is not None:
            result['ProjectData'] = self.project_data.to_map()

        if self.project_id is not None:
            result['projectId'] = self.project_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ProjectData') is not None:
            temp_model = main_models.OralEvaluationStatisticsErrorCountResponseProjectData()
            self.project_data = temp_model.from_map(m.get('ProjectData'))

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        return self

class OralEvaluationStatisticsErrorCountResponseProjectData(DaraModel):
    def __init__(
        self,
        application_data: List[main_models.OralEvaluationStatisticsErrorCountResponseProjectDataApplicationData] = None,
        application_internal_id: str = None,
    ):
        self.application_data = application_data
        # This parameter is required.
        self.application_internal_id = application_internal_id

    def validate(self):
        if self.application_data:
            for v1 in self.application_data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['ApplicationData'] = []
        if self.application_data is not None:
            for k1 in self.application_data:
                result['ApplicationData'].append(k1.to_map() if k1 else None)

        if self.application_internal_id is not None:
            result['applicationInternalId'] = self.application_internal_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.application_data = []
        if m.get('ApplicationData') is not None:
            for k1 in m.get('ApplicationData'):
                temp_model = main_models.OralEvaluationStatisticsErrorCountResponseProjectDataApplicationData()
                self.application_data.append(temp_model.from_map(k1))

        if m.get('applicationInternalId') is not None:
            self.application_internal_id = m.get('applicationInternalId')

        return self

class OralEvaluationStatisticsErrorCountResponseProjectDataApplicationData(DaraModel):
    def __init__(
        self,
        data: List[main_models.OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataData] = None,
        application_access_id: str = None,
    ):
        self.data = data
        # appId,appkey
        # 
        # This parameter is required.
        self.application_access_id = application_access_id

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.application_access_id is not None:
            result['applicationAccessId'] = self.application_access_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataData()
                self.data.append(temp_model.from_map(k1))

        if m.get('applicationAccessId') is not None:
            self.application_access_id = m.get('applicationAccessId')

        return self

class OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataData(DaraModel):
    def __init__(
        self,
        data: List[main_models.OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataDataData] = None,
        error_code: str = None,
        error_message: str = None,
    ):
        self.data = data
        self.error_code = error_code
        self.error_message = error_message

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.error_code is not None:
            result['ErrorCode'] = self.error_code

        if self.error_message is not None:
            result['ErrorMessage'] = self.error_message

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataDataData()
                self.data.append(temp_model.from_map(k1))

        if m.get('ErrorCode') is not None:
            self.error_code = m.get('ErrorCode')

        if m.get('ErrorMessage') is not None:
            self.error_message = m.get('ErrorMessage')

        return self

class OralEvaluationStatisticsErrorCountResponseProjectDataApplicationDataDataData(DaraModel):
    def __init__(
        self,
        count: int = None,
        name: str = None,
    ):
        # This parameter is required.
        self.count = count
        # This parameter is required.
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.count is not None:
            result['count'] = self.count

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('count') is not None:
            self.count = m.get('count')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_aicontent20240611 import models as main_models
from darabonba.model import DaraModel

class ApiKeyDTO(DaraModel):
    def __init__(
        self,
        client: main_models.ClientDTO = None,
        client_id: int = None,
        delete_tag: int = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        id: int = None,
        key: str = None,
        key_preview: str = None,
        name: str = None,
    ):
        self.client = client
        self.client_id = client_id
        self.delete_tag = delete_tag
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.id = id
        self.key = key
        self.key_preview = key_preview
        self.name = name

    def validate(self):
        if self.client:
            self.client.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client is not None:
            result['client'] = self.client.to_map()

        if self.client_id is not None:
            result['clientId'] = self.client_id

        if self.delete_tag is not None:
            result['deleteTag'] = self.delete_tag

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.id is not None:
            result['id'] = self.id

        if self.key is not None:
            result['key'] = self.key

        if self.key_preview is not None:
            result['keyPreview'] = self.key_preview

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('client') is not None:
            temp_model = main_models.ClientDTO()
            self.client = temp_model.from_map(m.get('client'))

        if m.get('clientId') is not None:
            self.client_id = m.get('clientId')

        if m.get('deleteTag') is not None:
            self.delete_tag = m.get('deleteTag')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('key') is not None:
            self.key = m.get('key')

        if m.get('keyPreview') is not None:
            self.key_preview = m.get('keyPreview')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ModelDTO(DaraModel):
    def __init__(
        self,
        api_key_preview: str = None,
        base_url: str = None,
        delete_tag: int = None,
        description: str = None,
        extensions: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        has_billing_rule: bool = None,
        id: int = None,
        in_out: str = None,
        is_custom: bool = None,
        max_input_length: str = None,
        max_output_length: str = None,
        model_code: str = None,
        model_type: str = None,
        name: str = None,
        symbol: str = None,
        tag_names: str = None,
        tags: str = None,
        version: int = None,
    ):
        self.api_key_preview = api_key_preview
        # Base URL
        self.base_url = base_url
        self.delete_tag = delete_tag
        self.description = description
        self.extensions = extensions
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.has_billing_rule = has_billing_rule
        # ID
        self.id = id
        self.in_out = in_out
        self.is_custom = is_custom
        self.max_input_length = max_input_length
        self.max_output_length = max_output_length
        self.model_code = model_code
        self.model_type = model_type
        self.name = name
        self.symbol = symbol
        self.tag_names = tag_names
        self.tags = tags
        self.version = version

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.api_key_preview is not None:
            result['apiKeyPreview'] = self.api_key_preview

        if self.base_url is not None:
            result['baseUrl'] = self.base_url

        if self.delete_tag is not None:
            result['deleteTag'] = self.delete_tag

        if self.description is not None:
            result['description'] = self.description

        if self.extensions is not None:
            result['extensions'] = self.extensions

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.has_billing_rule is not None:
            result['hasBillingRule'] = self.has_billing_rule

        if self.id is not None:
            result['id'] = self.id

        if self.in_out is not None:
            result['inOut'] = self.in_out

        if self.is_custom is not None:
            result['isCustom'] = self.is_custom

        if self.max_input_length is not None:
            result['maxInputLength'] = self.max_input_length

        if self.max_output_length is not None:
            result['maxOutputLength'] = self.max_output_length

        if self.model_code is not None:
            result['modelCode'] = self.model_code

        if self.model_type is not None:
            result['modelType'] = self.model_type

        if self.name is not None:
            result['name'] = self.name

        if self.symbol is not None:
            result['symbol'] = self.symbol

        if self.tag_names is not None:
            result['tagNames'] = self.tag_names

        if self.tags is not None:
            result['tags'] = self.tags

        if self.version is not None:
            result['version'] = self.version

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('apiKeyPreview') is not None:
            self.api_key_preview = m.get('apiKeyPreview')

        if m.get('baseUrl') is not None:
            self.base_url = m.get('baseUrl')

        if m.get('deleteTag') is not None:
            self.delete_tag = m.get('deleteTag')

        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('extensions') is not None:
            self.extensions = m.get('extensions')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('hasBillingRule') is not None:
            self.has_billing_rule = m.get('hasBillingRule')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('inOut') is not None:
            self.in_out = m.get('inOut')

        if m.get('isCustom') is not None:
            self.is_custom = m.get('isCustom')

        if m.get('maxInputLength') is not None:
            self.max_input_length = m.get('maxInputLength')

        if m.get('maxOutputLength') is not None:
            self.max_output_length = m.get('maxOutputLength')

        if m.get('modelCode') is not None:
            self.model_code = m.get('modelCode')

        if m.get('modelType') is not None:
            self.model_type = m.get('modelType')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('symbol') is not None:
            self.symbol = m.get('symbol')

        if m.get('tagNames') is not None:
            self.tag_names = m.get('tagNames')

        if m.get('tags') is not None:
            self.tags = m.get('tags')

        if m.get('version') is not None:
            self.version = m.get('version')

        return self

